Graph Analysis
==============

Call graph extraction, spectral partitioning, Kameda reachability, and
hierarchical decomposition.

.. automodule:: graph
   :members:
   :show-inheritance:

.. automodule:: graph.models
   :members:
   :show-inheritance:

.. automodule:: graph.extractor
   :members:
   :show-inheritance:

.. automodule:: graph.ast_extractor
   :members:
   :show-inheritance:

.. automodule:: graph.asr_extractor
   :members:
   :show-inheritance:

.. automodule:: graph.dependency_extractor
   :members:
   :show-inheritance:

.. automodule:: graph.spectral
   :members:
   :show-inheritance:

.. automodule:: graph.partitioner
   :members:
   :show-inheritance:

.. automodule:: graph.planarity
   :members:
   :show-inheritance:

.. automodule:: graph.kameda
   :members:
   :show-inheritance:

.. automodule:: graph.hierarchy
   :members:
   :show-inheritance:
